LaTeX
=====

This is going to be a compiler for a subset of LaTeX. TeX/LaTeX in
general is not a context free language ADD REFERENCE HERE. 
Thus, only a subset.

Presently, parser and AST-Transformation works.
